@@ -2,7 +2,6 @@ import argparse
 import sys
 import time
 import grpc
-import os
 from concurrent import futures
 import storage_pb2_grpc
 import storage_pb2
@@ -12,10 +11,10 @@ _ONE_DAY_IN_SECONDS = 60 * 60 * 24
 
 parser = argparse.ArgumentParser()
 
-if os.environ.get("STORAGE_EMULATOR_HOST") is None:
-    sys.exit(
-        "This benchmarking server only works when connected to an emulator. Please set STORAGE_EMULATOR_HOST."
-    )
+# if os.environ.get("STORAGE_EMULATOR_HOST") is None:
+#     sys.exit(
+#         "This benchmarking server only works when connected to an emulator. Please set STORAGE_EMULATOR_HOST."
+#     )
 
 parser.add_argument("--port", help="The port to run on.")
 
@@ -24,7 +23,8 @@ args = parser.parse_args()
 if args.port is None:
     sys.exit("Usage: python3 main.py --port 8081")
 
-client = storage.Client.create_anonymous_client()
+# client = storage.Client.create_anonymous_client()
+client = storage.Client()
 
 
 class StorageBenchWrapperServicer(storage_pb2_grpc.StorageBenchWrapperServicer):
